package AO_Set_Quota;

use strict;
use Quota;

use vars qw(@ISA);

@ISA = ("AO_Template");

# -----------------------------------------------------------------------------

my $menu_string = "\n " 
                . "\n Set Users Quota"
                . "\n ---------------"
                . "\n "
                . "\n Enter username (blank to quit), <return> : ";


# -----------------------------------------------------------------------------

sub new() {

  my $class     = shift;
  my $devel     = shift;
  my $logs      = shift;
  my $menus     = shift;
  my $yp_passwd = shift;
  my $config    = shift;

    my $self = { };

    bless($self, $class);

    $self->{MENU_STR} = $menu_string;

    $self->new_AO_template($devel, $logs, $menus, $yp_passwd, $config);

    return $self;
  }

# -----------------------------------------------------------------------------

sub do_it() {

    my $self     = shift;
    my $username = shift;

    $self->do_it_init($username);

    # -------------------------------------------------------------------------
    # -- STANDARD CHECKS :

    my ($one, $two) = $self->do_it_checks($username);
    if ($one) {return $two}


    # -------------------------------------------------------------------------
    # -- Load appropriate YP/NIS+/Flat thingy :

    my $auto_home_pm = $self->{CONFIG}->Auto_Home();
    require "$auto_home_pm.pm";
    my $auto_home 
       = $self->{CONFIG}->Auto_Home->new($self->{CONFIG}->auto_home(),
                                         $self->{CONFIG}, 
                                         $self->{DEVEL});

    # -------------------------------------------------------------------------
    # -- MODULE-SPECIFIC STUFF :

    # ...in which partition/slice is user's home-directory?
    my $slice = $auto_home->slice($username);

    # ...ensure we've found a good home for our user...
    if ($slice eq $auto_home->no_slice_found()) {
        $self->{MENUS}->message_clr("Can't find partition/slice for: " 
                                  . "$username");
        $self->{LOGS}->append("Can't find partition/slice for: $username");
        return;
      }

    my $uid = $self->{PASSWD}->uid($username);

    # ...get current quota-related info and display...
    my ($block_curr, $block_soft, $block_hard, $block_time_limit,
        $inode_curr, $inode_soft, $inode_hard, $inode_time_limit) 
           = Quota::query($slice, $uid);

    unless (defined $block_soft) {
	$self->{LOGS}->append("No assigned quota for: " 
                            . "$username, $slice, $uid");
        $self->{MENUS}->message("No assigned quota for: " 
                              . "$username, $slice, $uid");
	return;
      }

    my $info_str = 
        "\n Home dir: $slice"
      . "\n UID     : " . $self->{PASSWD}->uid($username)
      . "\n "
      . "\n Disk space currently used     :  " . $block_curr/1000 . " MB"
      . "\n Disk quota currently assigned :  " . $block_soft/1000 . " MB"
      . "\n "
      . "\n Enter new value in MB";

    my $new_quota = $self->{MENUS}->get_field($info_str);

    unless (defined $new_quota) {
        $self->{MENUS}->error_message($self->{CONFIG}->dave());
        return;
      }

    unless ($new_quota =~ /^\d+$/) {
        $self->{MENUS}->error_message($self->{CONFIG}->dave());
        return;
      }

    if ($new_quota < $block_soft/1000) {
        $self->{MENUS}->error_message("Cannot reduce diskspace quota!");
	return;
      }

    my $new_block_soft = $new_quota * 1000;
    my $new_block_hard = int(1.1 * $new_block_soft);
    my $new_inode_hard = int(1.1 * $inode_soft);

    # -- make it so :
    Quota::setqlim($slice, $uid, 
                   $new_block_soft, $new_block_hard, 
                   $inode_soft, $new_inode_hard,
                   0);

    $self->{LOGS}->append("Set new quota... slice: $slice, uid: $uid, "
                        . "new soft: $new_block_soft, "
                        . "new hard: $new_block_hard, "
                        . "new inode soft: $inode_soft, "
                        . "new inode hard: $new_inode_hard");

    $self->{MENUS}->message("Done!");
  }



# -----------------------------------------------------------------------------
1;
# -----------------------------------------------------------------------------
