# -----------------------------------------------------------------------------
package Home_Dirs;
# -----------------------------------------------------------------------------

use strict;

# -----------------------------------------------------------------------------
# --

sub new() {

  my $class  = shift;
  my $config = shift;
  my $devel  = shift;
  my $logs   = shift;

    my $self  = { };

    bless($self, $class);

    $self->{CONFIG} = $config;
    $self->{DEVEL}  = $devel;
    $self->{LOGS}   = $logs;

    $self->{DIRS}   = $config->home_dirs();

    return $self;
  }


# -----------------------------------------------------------------------------
# -- NEW ACCOUNT :
# -----------------------------------------------------------------------------

sub mk_new_home_dir() {
    my $self   = shift;
    my $uname  = shift;
    my $uid    = shift;
    my $gid    = shift;

    # ...recall that "system" returns true for failure...

    my $dir = $self->{CONFIG}->new_home_dir_partition();

    $self->{DEVEL}->marker("new home dir: $dir/$uname");

    my $ut_dir   = $dir;
    my $ut_uname = $uname;
    my $ut_uid   = $uid;
    my $ut_gid   = $gid;

    my $export = $self->{CONFIG}->export();

    unless ($ut_uname =~ m/^(m[a-z0-9]+)$/) {
        #$self->{DEVEL}->die("Tainted: $ut_uname");
        return (0, "Tainted ut_uname: $ut_uname")
      }
    $ut_uname = $1;

    unless ($ut_uid =~ m/^([0-9]+)$/) {
        #$self->{DEVEL}->die("Tainted: $ut_uid");
        return (0, "Tainted ut_uid: $ut_uid");
      }
    $ut_uid = $1;

    unless ($ut_gid =~ m/^([0-9]+)$/) {
        #$self->{DEVEL}->die("Tainted: $ut_gid");
        return (0, "Tainted ut_gid: $ut_gid");
      }
    $ut_gid = $1;

    unless ($ut_dir =~ m/^(
                         $export
                         \/u0\d?\s* # dir
                         )$/x) {
        #$self->{DEVEL}->die("Tainted: $ut_dir");
        return (0, "Tainted ut_dir: $ut_dir");
      }
    $ut_dir = $1;

    # -- actually do the stuff (recall 'system' returns reverse flag to
    #    everything else) :

    system("/usr/bin/mkdir $ut_dir/$ut_uname") 
        && #$self->{DEVEL}->die("Can't: /usr/bin/mkdir $ut_dir/$ut_uname");
	    return (0, "Can't: /usr/bin/mkdir $ut_dir/$ut_uname");

    $self->{LOGS}->append_new_acc("mkdir: $ut_dir/$ut_uname");

    system("/usr/bin/chmod 700 $ut_dir/$ut_uname")
        && #$self->{DEVEL}->die("Can't: /usr/bin/chmod 700 $ut_dir/$ut_uname");
           return (0, "Can't: /usr/bin/chmod 700 $ut_dir/$ut_uname");

    $self->{LOGS}->append_new_acc("chmod 700: $ut_dir/$ut_uname");

    system("/usr/bin/chown $ut_uid:$ut_gid $ut_dir/$ut_uname")
        && #$self->{DEVEL}->die("Can't: /usr/bin/chown " 
           #                  . "$ut_uid:$ut_gid $ut_dir/$ut_uname");
           return (0, "Can't: /usr/bin/chown " 
                    . "$ut_uid:$ut_gid $ut_dir/$ut_uname");

    $self->{LOGS}->append_new_acc("chown: $ut_uid:$ut_gid $ut_dir/$ut_uname");

    # -- success :
    return (1, "");
  }

# -----------------------------------------------------------------------------
# -- READ METHODS :
# -----------------------------------------------------------------------------

sub ls_l() {

    my $self       = shift;
    my @total_ls_l = ();

    foreach (@{$self->{DIRS}}) {
        my $ls_l = `/usr/bin/ls -l $_`;
        my @ls_l = split(/\n/, $ls_l);

        push(@total_ls_l, @ls_l);
      }

    return \@total_ls_l;
  }


# -----------------------------------------------------------------------------
1;
# -----------------------------------------------------------------------------
